| IntervalList-class | R Documentation |
S4 class representing a list of intervals
mid:A vector of real numbers saved as a numeric
object specifying the mid-points of the intervals.
spr:A vector of real numbers saved as a numeric
object specifying the spreads of the intervals.
José García-García garciagarjose@uniovi.es
Objects of IntervalList class should be created through
IntervalList() function. Besides IntervalList class,
the IntervalQuestionStat package also incorporates
IntervalData-class and IntervalMatrix-class
for dealing with interval-valued data in R environment.
showClass("IntervalList")
showMethods(classes = "IntervalList")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.