| IntervalMatrix-class | R Documentation |
S4 class representing a matrix of intervals
mid:A matrix of real numbers saved as a matrix
object specifying the mid-points of the intervals.
spr:A matrix of real numbers saved as a matrix
object specifying the spreads of the intervals.
José García-García garciagarjose@uniovi.es
Objects of IntervalMatrix class should be created through
IntervalMatrix() function. Besides IntervalMatrix class,
the IntervalQuestionStat package also incorporates
IntervalData-class and IntervalList-class
for dealing with interval-valued data in R environment.
showClass("IntervalMatrix")
showMethods(classes = "IntervalMatrix")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.